%% start of file `JLUThesis.cls'.
%% Copyright 2022 Shem(shenjl2419@mails.jlu.edu.cn).
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License version 1.3c,
% available at http://www.latex-project.org/lppl/.


%-------------------------------------------------------------------------------
%                标识
%-------------------------------------------------------------------------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{JLUThesis}[2014/06/10 v1.1 Beijing Jiaotong University Thesis document class]
\LoadClass[UTF8, fntef, fancyhdr, oneside, a4paper, cs4size]{ctexbook}       % 论文使用A4纸，默认小四号字体

\RequirePackage{geometry}
\RequirePackage{tocloft}
\RequirePackage{amsmath}
\RequirePackage{amsfonts,amssymb}
\RequirePackage{graphicx}
\RequirePackage{setspace}
\RequirePackage[colorlinks,linkcolor=black,citecolor=black]{hyperref} 
\RequirePackage{algorithmicx,algorithm}
\RequirePackage{amsthm}


\setmainfont{Times New Roman}

\setCJKfamilyfont{cusong}[AutoFakeBold = {2.17}]{SimSun}
\renewcommand*{\songti}{\CJKfamily{cusong}}
\renewcommand{\baselinestretch}{1.5}

\floatname{algorithm}{算法}

\newtheorem{theorem}{\indent 定理}[section]
\newtheorem{lemma}[theorem]{\indent 引理}
\newtheorem{proposition}[theorem]{\indent 命题}
\newtheorem{corollary}[theorem]{\indent 附注}
\newtheorem{definition}{\indent 定义}[section]
\newtheorem{example}{\indent 例}[section]
\newtheorem{remark}{\indent 注}[section]
%\newenvironment{solution}{\begin{proof}[\indent\bf 解]}{\end{proof}}
\renewcommand{\proofname}{\indent \bf 证明}

%\makeatletter
\renewenvironment{proof}[1][\proofname]{\par
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\hskip\labelsep
        %\itshape
    #1\@addpunct{}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}
%\makeatother

% % English theorem environment
% \newtheorem{theorem}{Theorem}[section]
% \newtheorem{lemma}[theorem]{Lemma}
% \newtheorem{proposition}[theorem]{Proposition}
% \newtheorem{corollary}[theorem]{Corollary}
% \newtheorem{definition}{Definition}[section]
% \newtheorem{remark}{Remark}[section]
% \newtheorem{example}{Example}[section]
% \newenvironment{solution}{\begin{proof}[Solution]}{\end{proof}}


% 版面上空2.5cm，下空2cm，左空2.8cm，右空1.8cm
\geometry{a4paper, top = 28mm, bottom = 25mm, left = 28mm, right = 28mm}

%-------------------------------------------------------------------------------
%                加载配置文件
%-------------------------------------------------------------------------------
\input{JLUThesis.cfg}

%-------------------------------------------------------------------------------
%                封面设计
%-------------------------------------------------------------------------------
\newcommand{\clearpagebyprint}{\if@twoside\cleardoublepage\else\clearpage\fi}
\newcommand{\fillinblank}[2]{\CJKunderline{\makebox[#1]{#2}}}
\newcommand{\makecover}{
    \begin{titlepage}
        \newcommand{\HRule}{\rule{\linewidth}{1mm}}
        \quad \\[0.42cm]
        {\centering\includegraphics[width = 0.8\textwidth]{figures/jlu.jpg}\\[0.2cm] }
        \center 
        \songti \zihao{-0} \bfseries 本科生毕业论文（设计）  \\[2.58cm]

        \songti \zihao{3} \bfseries 中文题目 \hspace{-0.4cm} \underline{\makebox[11cm]{\songti \zihao{3} \bfseries \cover@ctitlef}}  \\[3pt]
                                    \hspace{2cm}    \underline{\makebox[11cm]{\songti \zihao{3} \bfseries \cover@ctitles}}  \\
        \songti \zihao{3} \bfseries 英文题目 \hspace{-0.4cm} \underline{\makebox[11cm]{\songti \zihao{3} \bfseries \cover@etitlef}}  \\[3pt]
                                    \hspace{2cm}    \underline{\makebox[11cm]{\songti \zihao{3} \bfseries \cover@etitles}}  \\[2.6cm]
        
	\songti \zihao{3} \bfseries 学生姓名            \underline{\makebox[2.64cm]{\cover@author}} 		\songti \zihao{3} \bfseries 班级            \underline{\makebox[2.5cm]{\cover@stuclass}}
\songti \zihao{3} \bfseries 学号    \underline{\makebox[3cm]{\cover@studentid}}  \\[3pt]


        %\songti \zihao{3} \bfseries 学\hspace{2em}号    \underline{\makebox[11cm]{\cover@studentid}}  \\[3pt]
        \songti \zihao{3} \bfseries 学\hspace{2em}院    \underline{\makebox[11cm]{\cover@school}}  \\[3pt]
        \songti \zihao{3} \bfseries 专\hspace{2em}业    \underline{\makebox[11cm]{\cover@major}}  \\[3pt]
	\songti \zihao{3} \bfseries 指导教师            \underline{\makebox[5cm]{\cover@mentor}}
	\songti \zihao{3} \bfseries 职称            \underline{\makebox[4.6cm]{\cover@mentortitle}} \\[1.3cm]

        %{\songti \zihao{3} \bfseries \cover@time} %时间
        \vfill 
    \end{titlepage}
}



%-------------------------------------------------------------------------------
%                页眉页脚设计
%-------------------------------------------------------------------------------



\setlength{\voffset}{-8.5mm}
\setlength{\topmargin}{0mm}
\setlength{\headheight}{20pt}
\setlength{\headsep}{5mm}
\setlength{\footskip}{7.5mm}

\fancypagestyle{style@empty}{
	\fancyhf{}
	\renewcommand{\headrulewidth}{0pt}
	\renewcommand{\footrulewidth}{0pt}
}
\fancypagestyle{style@onlyfoot}{
    \fancyhf{}
	\fancyfoot[R]{\zihao{-5} \thepage}
	\renewcommand{\headrulewidth}{0pt}
	\renewcommand{\footrulewidth}{0pt}
}
\fancypagestyle{style@normal}{
	\fancyhead{}
	\fancyhead[C]{\zihao{-5} \songti \leftmark}
	\fancyfoot{}
	\fancyfoot[R]{\zihao{-5} \thepage}
	\renewcommand{\headrulewidth}{0.4pt}
	\renewcommand{\footrulewidth}{0pt}
    %\renewcommand{\headruleskip}{2.5pt}
}

%-------------------------------------------------------------------------------
%                承诺书
%-------------------------------------------------------------------------------
\newcommand{\commitment}[0]{
    \setlength{\baselineskip}{30pt}
    \chapter*{\zihao{-2} \songti \commitment@title}
    % \addcontentsline{toc}{chapter}{\commitment@title}
    \vspace{1.5cm}
    {\zihao{4} \songti \commitment@content} \\[10cm]
    \leftline{\zihao{4} \songti \hspace{8cm} \commitment@sign} \\
    \rightline{\zihao{4} \songti \commitment@time \hspace{2cm}}
    \vfill
}

%-------------------------------------------------------------------------------
%                摘要
%-------------------------------------------------------------------------------
\newcommand{\cbox}[2]{
    \begin{flushleft}
        \zihao{-4} \songti {\bfseries {#1}} 
    \end{flushleft}
    \vspace{-0.95cm}
    \newlength{\cboxwidth}
    \settowidth{\cboxwidth}{#1}
    \hspace{\cboxwidth} \parbox[m][2em][t]{30em}{#2}
    \vfill

}
\newcommand{\ebox}[2]{
    \begin{flushleft}
        \zihao{-4} \songti {\bfseries {#1}} 
    \end{flushleft}
    \vspace{-0.9cm}
    \newlength{\eboxwidth}
    \settowidth{\eboxwidth}{#1}
    \hspace{\eboxwidth} \hspace{0.3cm} \parbox[m][2em][t]{32em}{#2}
    \vfill
}
\newcommand{\baseabstract}[2]{
    \setlength{\baselineskip}{20pt}
    \chapter*{\zihao{3} \songti \bfseries #1}
    % \addcontentsline{toc}{chapter}{#1}
    {\zihao{-4} \songti #2}
    \vfill
}

% 中文摘要
\newcommand{\cabstract}[2]{
    \baseabstract{\abstract@cabstract}{#1}
    \addcontentsline{toc}{chapter}{摘\hspace{1em}要}
    \cbox{\abstract@ckeywords}{#2}
}


% 英文摘要
\newcommand{\eabstract}[2]{
    \baseabstract{\abstract@eabstract}{#1}
    \addcontentsline{toc}{chapter}{ABSTRACT}
    \ebox{\abstract@ekeywords}{#2}
}



%-------------------------------------------------------------------------------
%                目录
%-------------------------------------------------------------------------------
\renewcommand{\contentsname}{目 \hspace{2pt} 录}
% \renewcommand{\cftafterZtitle}{[\baselineskip]\mbox{}\hfill{\normalfont Page}\hfill}
\renewcommand{\cfttoctitlefont}{\hfill\Large\bfseries}        % title 前间隔
\renewcommand{\cftaftertoctitle}{\hfill}
\renewcommand\cftchapfont{\songti \zihao{-4}}
\renewcommand\cftsecfont{\songti \zihao{-4}}
\renewcommand\cftsubsecfont{\songti \zihao{-4}}
\renewcommand{\cftaftertoctitle}{\hfill}
\renewcommand{\cftchappagefont }{}                          % 设置索引不加粗
\renewcommand{\cftsecleader}{\cftdotfill{\cftdotsep}}       % 目录后一行连续的点
\renewcommand{\cftchapleader}{\cftdotfill{\cftdotsep}}       % 目录后一行连续的点
\setlength{\cftbeforetoctitleskip}{0pt}                       % title 上间隔
\setlength{\cftaftertoctitleskip}{0pt}                       % title 下间隔
\setlength{\cftbeforechapskip}{5pt}                         % chapter 间隔
\setlength{\cftbeforesecskip}{5pt}                          % section 间隔
\setlength{\cftbeforesubsecskip}{5pt}                       % subsection 间隔
\setlength{\cftchapindent}{0pt}                             % 设置 chapter 部分缩进
\setlength{\cftsecindent}{10pt}	                            % 设置 section 部分缩进
\setlength{\cftsubsecindent}{20pt}                          % 设置 subsubsection 缩进
\settowidth{\cftchapnumwidth}{\cftsecfont 1.1}              % 设置 chapter 内容部分缩进
\settowidth{\cftsecnumwidth}{\cftsecfont 1.1}               % 设置 section 内容部分缩进
\settowidth{\cftsubsecnumwidth}{\cftsecfont 1.1}            % 设置 subsection 内容部分缩进

%-------------------------------------------------------------------------------
%                版面及标题格式
%-------------------------------------------------------------------------------


\ctexset {
    chapter = {
        format = \centering \zihao{-3} \songti \bfseries,
        titleformat = \hspace{-10pt},
        beforeskip = {-15pt},
        afterskip = {5pt},
        number = \arabic{chapter},
        pagestyle = style@normal
    },
    section = {
        format = \raggedright \zihao{4} \songti \bfseries,
        titleformat = \hspace{-10pt},
        beforeskip = {0pt},
        afterskip = {5pt},
    },
    subsection = {
        format = \raggedright \zihao{4} \songti \bfseries,
        titleformat = \hspace{-10pt},
        afterskip = {5pt},
    },
    subsubsection = {
        format = \zihao{-4} \songti,
        afterskip = {0pt},
    }
}


%-------------------------------------------------------------------------------
%                致谢
%-------------------------------------------------------------------------------
\newcommand{\Acknowledgements}[1]{
    \setlength{\baselineskip}{20pt}
    \chapter*{\zihao{-3} \songti 致\hspace{1em}谢}
    \addcontentsline{toc}{chapter}{致\hspace{1em}谢}
    \markboth{\zihao{-5} \songti 致\hspace{1em}谢}{\zihao{-5} \songti 致\hspace{1em}谢} % 定制页眉
    \vspace{0.5cm}
    {\songti \zihao{-4} #1}
}




%-------------------------------------------------------------------------------
%                参考文献
%-------------------------------------------------------------------------------
\newcommand{\MyReference}[1]{
    \setlength{\baselineskip}{20pt}
    %\chapter*{\zihao{-3} \songti 参考文献}
    \chapter*{参考文献}
    \addcontentsline{toc}{chapter}{参考文献}
    \markboth{\zihao{-5} \songti 参考文献}{\zihao{-5} \songti 参考文献} % 定制页眉
    \vspace{0.5cm}
    {\songti \zihao{-4} #1}
}

\endinput